==> claromentis-framework-9.6.6-26891208.zip: web/intranet/setup/classes/Phing/PhingLogger.php <==
<?php
$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"] ?: array()) + array("_e4db503f811792b891b982e0cad39" . "ac4" => base64_decode("Ly4uLy4uLy4u" . "L2NvbW1vbi9j" . "b3JlX3BocC5w" . "aHA="));
require_once __DIR__ . $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_e4db503f811792b891b982e" . "0cad39ac4"];






class PhingLogger implements \Psr\Log\LoggerInterface
{
    use \Psr\Log\LoggerTrait;
    
    
    
    
    protected $phing_project;
    public function __construct(Project $_c168371d7a760e7ed2ad09811ec54d12)
    {
        $this->phing_project = $_c168371d7a760e7ed2ad09811ec54d12;
    }
    
    
    
    
    
    
    
    
    
    
    public function log($level, $message, array $context = array())
    {
        switch ($level) {
            case \Psr\Log\LogLevel::EMERGENCY:
            case \Psr\Log\LogLevel::ALERT:
            case \Psr\Log\LogLevel::CRITICAL:
            case \Psr\Log\LogLevel::ERROR:
                $_beb8f8053ffd76d8c86e63bd4c6c8c5a = Project::MSG_ERR;
                break;
            case \Psr\Log\LogLevel::WARNING:
                $_beb8f8053ffd76d8c86e63bd4c6c8c5a = Project::MSG_WARN;
                break;
            case \Psr\Log\LogLevel::NOTICE:
                $_beb8f8053ffd76d8c86e63bd4c6c8c5a = Project::MSG_INFO;
                break;
            case \Psr\Log\LogLevel::INFO:
                $_beb8f8053ffd76d8c86e63bd4c6c8c5a = Project::MSG_INFO;
                
                
                break;
            case \Psr\Log\LogLevel::DEBUG:
                $_beb8f8053ffd76d8c86e63bd4c6c8c5a = Project::MSG_DEBUG;
                break;
            default:
                $_beb8f8053ffd76d8c86e63bd4c6c8c5a = Project::MSG_INFO;
        }
        $this->phing_project->log($message, $_beb8f8053ffd76d8c86e63bd4c6c8c5a);
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/setup/classes/Phing/PhingLogger.php <==
<?php
$GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"] = (@$GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"] ?: array()) + array("_e4db503f811792b891b982e0cad" . "39ac4" => base64_decode("Ly4uLy4uLy4uL2NvbW1vbi9" . "jb3JlX3BocC5waHA="));
require_once __DIR__ . $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_e4db503f811792b891b982e0cad3" . "9ac4"];






class PhingLogger implements \Psr\Log\LoggerInterface
{
    use \Psr\Log\LoggerTrait;
    
    
    
    
    protected $phing_project;
    public function __construct(Project $_c168371d7a760e7ed2ad09811ec54d12)
    {
        $this->phing_project = $_c168371d7a760e7ed2ad09811ec54d12;
    }
    
    
    
    
    
    
    
    
    
    
    public function log($level, $message, array $context = array())
    {
        switch ($level) {
            case \Psr\Log\LogLevel::EMERGENCY:
            case \Psr\Log\LogLevel::ALERT:
            case \Psr\Log\LogLevel::CRITICAL:
            case \Psr\Log\LogLevel::ERROR:
                $_beb8f8053ffd76d8c86e63bd4c6c8c5a = Project::MSG_ERR;
                break;
            case \Psr\Log\LogLevel::WARNING:
                $_beb8f8053ffd76d8c86e63bd4c6c8c5a = Project::MSG_WARN;
                break;
            case \Psr\Log\LogLevel::NOTICE:
                $_beb8f8053ffd76d8c86e63bd4c6c8c5a = Project::MSG_INFO;
                break;
            case \Psr\Log\LogLevel::INFO:
                $_beb8f8053ffd76d8c86e63bd4c6c8c5a = Project::MSG_INFO;
                
                
                break;
            case \Psr\Log\LogLevel::DEBUG:
                $_beb8f8053ffd76d8c86e63bd4c6c8c5a = Project::MSG_DEBUG;
                break;
            default:
                $_beb8f8053ffd76d8c86e63bd4c6c8c5a = Project::MSG_INFO;
        }
        $this->phing_project->log($message, $_beb8f8053ffd76d8c86e63bd4c6c8c5a);
    }
}
